@@ -3,7 +3,7 @@ import json
 from tastypie.serializers import Serializer
         
 class QuizJSONSerializer(Serializer):
-    json_indent = 4
+    json_indent = 0
     def to_json(self, data, options=None):
         options = options or {}
         data = self.to_simple(data, options)
@@ -61,12 +61,11 @@ class QuizJSONSerializer(Serializer):
         return data  
     
 class QuizAttemptJSONSerializer(Serializer):
-    json_indent = 4
+    json_indent = 0
 
     def to_json(self, data, options=None):
         options = options or {}
         data = self.to_simple(data, options)
         if 'responses' in data:
             del data['responses']
-        return json.dumps(data,
-                sort_keys=True, ensure_ascii=False, indent=self.json_indent)
\ No newline at end of file
+        return json.dumps(data, sort_keys=True, ensure_ascii=False, indent=self.json_indent)
\ No newline at end of file
